@@ -43,7 +43,7 @@ class AISAPLibrary:
         
         self.notifikasi_login = {
             'Popup Change Password' : 'Failed to login, Please create new password!',
-            'Failed Login Attempt' : 'Succes Login'
+            'Failed Login Attempt' : 'Success Login'
         }
 
         self.sapapp = -1
@@ -812,8 +812,6 @@ class AISAPLibrary:
             
                 ${status}    ${msg}=    Login Sap    ${config}
             
-                Run Keyword If    ${status}==${False}    Fatal Error    ${msg}
-            
             """
             
         call([r'C:/Program Files (x86)/SAP/FrontEnd/SAPgui/saplogon.exe'])
@@ -832,15 +830,14 @@ class AISAPLibrary:
         self.input_password("wnd[0]/usr/pwdRSYST-BCODE",config["password"])
         self.input_text("wnd[0]/usr/txtRSYST-MANDT",config['client'])
         self.send_vkey(0)
-                
-        status = True
-        msg = None
+        
+        
+        msg = "Success Login"
         
         try:
             self.session.findById("wnd[1]/usr/pwdRSYST-NCODE")
             msg = self.notifikasi_login['Popup Change Password']
             self.click_element('wnd[1]/tbar[0]/btn[12]')
-            return False, msg 
         except:
             pass
             
@@ -848,7 +845,6 @@ class AISAPLibrary:
             self.session.findById("wnd[1]/usr/txtIK1")
             self.click_element('wnd[1]/tbar[0]/btn[0]')
             msg = self.notifikasi_login['Failed Login Attempt']
-            return True, msg 
         except:
             pass
         
@@ -856,16 +852,17 @@ class AISAPLibrary:
             self.session.findById("wnd[1]/usr/lbl%#AUTOTEXT001")
             msg = self.get_value('wnd[1]/usr/txtMULTI_LOGON_TEXT')
             self.click_element('wnd[1]/tbar[0]/btn[12]')
-            return False, msg 
         except:
             pass
             
         try:
             self.session.findById("wnd[0]/usr/txtRSYST-BNAME")
             msg = self.get_value('wnd[0]/sbar/pane[0]')
-            return False, msg 
         except:
             pass               
-            
-        return status, msg 
+        
+        if msg=="Success Login":
+            pass
+        else :
+            raise RuntimeError(msg)
     
\ No newline at end of file
